@@ -1,9 +1,7 @@
+# $Horde: horde/scripts/database/mysql_create.sql,v 1.1.2.8 2000/09/02 00:49:28 jon Exp $
 #
-#   File: mysql_create.sql
-#   $Horde: horde/scripts/database/mysql_create.sql,v 1.1.2.5 2000/07/31 12:49:13 bjn Exp $
-#
-#   You can simply direct this file to mysql as STDIN:
-#   $ mysql (user/pass/host args) < mysql_create.sql
+# You can simply direct this file to mysql as STDIN:
+# $ mysql (user/pass/host args) < mysql_create.sql
 
 CONNECT mysql;
 
@@ -33,30 +31,31 @@ CREATE DATABASE horde;
 CONNECT horde;
 
 CREATE TABLE active_sessions (
-    sid varchar(32) DEFAULT '' NOT NULL,
-    name varchar(32) DEFAULT '' NOT NULL,
-    val text,
-    changed varchar(14) DEFAULT '' NOT NULL,
-    PRIMARY KEY (name,sid),
-    KEY changed (changed)
+    sid         varchar(32) not null,
+    name        varchar(32) not null,
+    val         text,
+    changed     varchar(14) not null,
+    primary key (name, sid),
+    key changed (changed)
 );
 
 # create the address table
 CREATE TABLE imp_addr (
-    user text,
-    address text,
-    nickname text,
-    fullname text
+    user        varchar(120) not null,
+    address     varchar(120) not null,
+    nickname    varchar(255),
+    fullname    varchar(255),
+    primary key (user, address)
 );
 
 
 # now create the pref table
 CREATE TABLE imp_pref (
-    user text,
-    fullname text,
-    replyto text,
-    lang varchar(30),
-    sig text
+    user        varchar(255) not null primary key,
+    fullname    varchar(70),
+    replyto     varchar(70),
+    lang        varchar(30),
+    sig         text
 );
 
 FLUSH PRIVILEGES;
